# django-docrootcms-tagulous
Fork of tagulous with patch for Django3

NOTE: this should not be used unless you are installing the docrootcms which requires django2.2 or above.  I am using this fork until the official tagulous branch is updated to remove legacy code and support django3.

Official Repo: http://radiac.net/projects/django-tagulous/

Source: https://github.com/radiac/django-tagulous


Bug Report for not supporting Django 3.x: https://github.com/radiac/django-tagulous/issues/85


Special thanks to ensignavenger for providing a patch for python3.8 django3.x here:  https://github.com/ensignavenger/tagulous

I will remove this dependency and reference the official library once this bug is resolved.
